import{_ as n}from"./TasksView.vue_vue_type_script_setup_true_lang.6ca79f7a.js";import{L as i}from"./tasksController.bbd2773f.js";import{d as c,o as p,c as d,w as o,b as s,aG as _,u as a,dd as m,a0 as l}from"./index.0050062d.js";import{C as u}from"./ContentLayout.9fcaf9f3.js";import"./metadata.9ee2261a.js";import"./PhWebhooksLogo.vue.33edc1e9.js";import"./string.867fe8ae.js";import"./ant-design.2b9c7b39.js";import"./dayjs.c970e348.js";import"./index.7afe76ca.js";import"./gateway.60411ad8.js";import"./popupNotifcation.675f1b12.js";import"./polling.56c8a3d2.js";import"./scripts.c68ba376.js";import"./record.ed103436.js";import"./linters.d48779d0.js";import"./asyncComputed.5a9dc807.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="807e0c45-ec59-405d-9c0e-906860905cbb",e._sentryDebugIdIdentifier="sentry-dbid-807e0c45-ec59-405d-9c0e-906860905cbb")}catch{}})();const f=c({__name:"Tasks",setup(e){const t=new i;return(r,y)=>(p(),d(u,null,{default:o(()=>[s(a(m),null,{default:o(()=>[_("Tasks")]),_:1}),s(n,{class:"tasks",api:a(t),stages:null,editor:""},null,8,["api"])]),_:1}))}});const G=l(f,[["__scopeId","data-v-10aa4cc9"]]);export{G as default};
//# sourceMappingURL=Tasks.74b0bd22.js.map
