import{B as d}from"./BookOutlined.9a32f29a.js";import{d as c,o,c as l,w as a,b as f,u as n,$ as u,Y as i,aG as p,aS as b,bT as y}from"./index.0050062d.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="58290257-6d85-4c37-971c-135514c51eb0",t._sentryDebugIdIdentifier="sentry-dbid-58290257-6d85-4c37-971c-135514c51eb0")}catch{}})();const g=c({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var s;return o(),l(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank",type:"text",size:"small"},{icon:a(()=>[f(n(d))]),default:a(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(o(),i(b,{key:1},[p("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.60f08b82.js.map
