import"./App.vue_vue_type_style_index_0_lang.811792fe.js";import{_ as b}from"./App.vue_vue_type_style_index_0_lang.811792fe.js";import"./workspaceStore.ccb2ec4f.js";import"./index.0050062d.js";import"./url.3865bbae.js";import"./colorHelpers.16cd7470.js";import"./PlayerConfigProvider.2bd88e7c.js";import"./index.cbd826a6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c7f5cb00-58c7-4503-8519-4cd4974fed5c",e._sentryDebugIdIdentifier="sentry-dbid-c7f5cb00-58c7-4503-8519-4cd4974fed5c")}catch{}})();export{b as default};
//# sourceMappingURL=App.848a1515.js.map
