import{L as t}from"./Logo.22e82baf.js";import{d as n,o as r,c as a,u as d}from"./index.0050062d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="664094b9-44b9-4ae9-8d66-887c5b93b8de",e._sentryDebugIdIdentifier="sentry-dbid-664094b9-44b9-4ae9-8d66-887c5b93b8de")}catch{}})();const i="/assets/logo.0faadfa2.svg",u=n({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(o,s)=>(r(),a(t,{"image-url":d(i),"brand-name":"Abstra","hide-text":o.hideText,size:o.size},null,8,["image-url","hide-text","size"]))}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.d93ccbf9.js.map
