import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.6ca79f7a.js";import{R as f}from"./tasksController.bbd2773f.js";import{d as b,ea as _,f as y,o as n,Y as g,b as w,w as k,u as l,c as I,S as T,aS as v,aG as B,dd as S}from"./index.0050062d.js";import"./gateway.60411ad8.js";import{a as j,B as x}from"./build.f67d9bd4.js";import{a as C}from"./project.6685d930.js";import"./tables.2e0419c1.js";import{a as D}from"./asyncComputed.5a9dc807.js";import"./metadata.9ee2261a.js";import"./PhWebhooksLogo.vue.33edc1e9.js";import"./string.867fe8ae.js";import"./ant-design.2b9c7b39.js";import"./dayjs.c970e348.js";import"./index.7afe76ca.js";import"./polling.56c8a3d2.js";import"./scripts.c68ba376.js";import"./record.ed103436.js";import"./linters.d48779d0.js";import"./popupNotifcation.675f1b12.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="2b788021-e9ee-4775-85c8-db015b934858",e._sentryDebugIdIdentifier="sentry-dbid-2b788021-e9ee-4775-85c8-db015b934858")}catch{}})();const Q=b({__name:"Tasks",setup(e){const s=_().params.projectId,p=new f(s),{result:o}=D(async()=>{const r=(await j.list(s)).find(c=>c.latest);if(!r)return null;const[u,d]=await Promise.all([x.get(r.id),C.get(s)]);return{buildSpec:u,project:d}}),i=y(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(n(),g(v,null,[w(l(S),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(n(),I(m,{key:0,class:"tasks",api:l(p),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{Q as default};
//# sourceMappingURL=Tasks.7e3d80b7.js.map
