import{d as n,o as s,Y as d,a,$ as c,ed as r,a0 as l}from"./index.0050062d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="eebccf90-fb47-439b-becf-629cc9b31d99",e._sentryDebugIdIdentifier="sentry-dbid-eebccf90-fb47-439b-becf-629cc9b31d99")}catch{}})();const _={class:"content-layout"},f=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(s(),d("div",_,[a("div",{class:r(["centered-layout",{"full-width":t.fullWidth}])},[c(t.$slots,"default",{},void 0,!0)],2)]))}});const i=l(f,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.9fcaf9f3.js.map
