import{k as n,T as a,m as r,P as o,C as d,M as p,s as c,n as s,p as f,q as m,t as u,v as g}from"./index.0050062d.js";import{s as y,c as l,a as i}from"./workspaceStore.ccb2ec4f.js";import{_ as w}from"./App.vue_vue_type_style_index_0_lang.811792fe.js";import"./url.3865bbae.js";import"./colorHelpers.16cd7470.js";import"./PlayerConfigProvider.2bd88e7c.js";import"./index.cbd826a6.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="ccf4fd22-4657-4235-98f0-5ede253e80a9",t._sentryDebugIdIdentifier="sentry-dbid-ccf4fd22-4657-4235-98f0-5ede253e80a9")}catch{}})();class _{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await y();const t=l(),e=n({render:()=>f(w)});a.init(),r(e,i),_.init(),e.use(i),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",p),e.component("Message",c),s(e,m),s(e,u),s(e,g)})();
//# sourceMappingURL=player.2c01ec5d.js.map
