import{U as s,dA as i,dB as c}from"./index.0050062d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="9d6ed993-e3af-4599-8b83-e6bd24166da0",e._sentryDebugIdIdentifier="sentry-dbid-9d6ed993-e3af-4599-8b83-e6bd24166da0")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:d,RangePicker:a}=i(c),u=s(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:a,TimePicker:m,QuarterPicker:d,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(r.name,r),e.component(t.name,t),e.component(d.name,d),e)});export{u as D,r as M,d as Q,a as R,t as W};
//# sourceMappingURL=dayjs.c970e348.js.map
