import{O as r}from"./workspaceStore.ccb2ec4f.js";import{d as c,X as i,o as l,Y as u,b as t,w as n,u as o,aG as d,dd as f,dc as b}from"./index.0050062d.js";import"./url.3865bbae.js";import"./colorHelpers.16cd7470.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="c544f8bc-447f-44fa-a4ad-5a9debc4e88c",e._sentryDebugIdIdentifier="sentry-dbid-c544f8bc-447f-44fa-a4ad-5a9debc4e88c")}catch{}})();const w=c({__name:"OidcLoginCallback",setup(e){return i(async()=>{await new r().loginCallback()}),(a,s)=>(l(),u("div",null,[t(o(f),null,{default:n(()=>[d("You're authenticated")]),_:1}),t(o(b),null,{default:n(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.0a050829.js.map
