import{d as i,o as p,c as n,w as m,b as a,u as t}from"./index.0050062d.js";import"./linters.d48779d0.js";import{W as s}from"./workspaces.f53d3f29.js";import{C as d}from"./ContentLayout.9fcaf9f3.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.8107ad26.js";import"./asyncComputed.5a9dc807.js";import"./workspaceStore.ccb2ec4f.js";import"./url.3865bbae.js";import"./colorHelpers.16cd7470.js";import"./record.ed103436.js";import"./gateway.60411ad8.js";import"./popupNotifcation.675f1b12.js";import"./fetch.107fe5c1.js";import"./SaveButton.420f9186.js";import"./UnsavedChangesHandler.83b1e50a.js";import"./ExclamationCircleOutlined.b19d6975.js";import"./CrudView.6122e2de.js";import"./router.22eb3290.js";import"./Badge.3d214d5b.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.60f08b82.js";import"./BookOutlined.9a32f29a.js";import"./PhDotsThreeVertical.vue.24d42b16.js";import"./index.7afe76ca.js";import"./index.58609537.js";import"./polling.56c8a3d2.js";import"./PhPencil.vue.80955bf1.js";import"./index.b19a5315.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="5dbb600d-b8e9-4047-aa23-f279b25c8d70",o._sentryDebugIdIdentifier="sentry-dbid-5dbb600d-b8e9-4047-aa23-f279b25c8d70")}catch{}})();const G=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(e,u)=>(p(),n(d,null,{default:m(()=>[a(f,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{G as default};
//# sourceMappingURL=EnvVarsEditor.8f3863ec.js.map
