import"./index.0050062d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="097d98e8-e6be-46dc-82dd-1133265d9ad6",e._sentryDebugIdIdentifier="sentry-dbid-097d98e8-e6be-46dc-82dd-1133265d9ad6")}catch{}})();const l=1e3,r=e=>{let n=null;return{startPolling:()=>{const t=async()=>{var d;try{!document.hidden&&!e.keepPollingOnOutOfFocus&&await e.task()}finally{n=setTimeout(t,(d=e.interval)!=null?d:l)}};t()},endPolling:()=>{n&&clearTimeout(n)}}};export{r as u};
//# sourceMappingURL=polling.56c8a3d2.js.map
