import{d as o,o as a,Y as s,b as d,u as c,by as r,a0 as _}from"./index.0050062d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="8665dd34-b4ce-43cc-9a06-f52689f62c68",e._sentryDebugIdIdentifier="sentry-dbid-8665dd34-b4ce-43cc-9a06-f52689f62c68")}catch{}})();const i={class:"centered"},f=o({__name:"LoadingContainer",setup(e){return(n,t)=>(a(),s("div",i,[d(c(r))]))}});const u=_(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.239af732.js.map
