import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.8107ad26.js";import{d as i,ea as s,o as a,c as m,u as d}from"./index.0050062d.js";import"./gateway.60411ad8.js";import"./popupNotifcation.675f1b12.js";import"./fetch.107fe5c1.js";import"./record.ed103436.js";import"./SaveButton.420f9186.js";import"./UnsavedChangesHandler.83b1e50a.js";import"./ExclamationCircleOutlined.b19d6975.js";import"./CrudView.6122e2de.js";import"./router.22eb3290.js";import"./Badge.3d214d5b.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.60f08b82.js";import"./BookOutlined.9a32f29a.js";import"./url.3865bbae.js";import"./PhDotsThreeVertical.vue.24d42b16.js";import"./index.7afe76ca.js";import"./index.58609537.js";import"./asyncComputed.5a9dc807.js";import"./polling.56c8a3d2.js";import"./PhPencil.vue.80955bf1.js";import"./index.b19a5315.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b9177aee-6737-40d4-ae43-bce930a3edbd",e._sentryDebugIdIdentifier="sentry-dbid-b9177aee-6737-40d4-ae43-bce930a3edbd")}catch{}})();const A=i({__name:"EnvVars",setup(e){const r=s().params.projectId,t=new p(r);return(c,u)=>(a(),m(n,{"env-var-repository":d(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.0a7d39be.js.map
