import{a0 as t,r as s,o as r,c as a}from"./index.0050062d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="771642ee-114a-4e3e-81a8-6ff02a8ca718",e._sentryDebugIdIdentifier="sentry-dbid-771642ee-114a-4e3e-81a8-6ff02a8ca718")}catch{}})();const c={};function _(e,o){const n=s("RouterView");return r(),a(n,{class:"router"})}const f=t(c,[["render",_],["__scopeId","data-v-3c2b9654"]]);export{f as default};
//# sourceMappingURL=Home.559d92d4.js.map
